@@ -359,7 +359,7 @@ end
 class Merb::BootLoader::Dependencies < Merb::BootLoader
 
   # ==== Returns
-  # Array[Gem::Dependency]:: The dependencies regiestered in init.rb.
+  # Array[Gem::Dependency]:: The dependencies registered in init.rb.
   #
   # :api: plugin
   cattr_accessor :dependencies
@@ -418,6 +418,7 @@ class Merb::BootLoader::Dependencies < Merb::BootLoader
   rescue LoadError
     gem "json_pure"
     require "json/pure"
+    require "merb-core/core_ext/json_pure_fix"
   end
 
   # Resets the logger and sets the log_stream to Merb::Config[:log_file]
@@ -515,9 +516,11 @@ class Merb::BootLoader::Dependencies < Merb::BootLoader
     #
     # :api: private
     def self.load_initfile
+      return nil if Merb.const_defined?("INIT_RB_LOADED")
       if File.exists?(initfile)
         STDOUT.puts "Loading init file from #{initfile}" unless Merb.testing?
         load(initfile)
+        Merb.const_set("INIT_RB_LOADED", true)
       elsif !Merb.testing?
         Merb.fatal! "You are not in a Merb application, or you are in " \
           "a flat application and have not specified the init file. If you " \
@@ -1266,6 +1269,8 @@ class Merb::BootLoader::ChooseAdapter < Merb::BootLoader
   #
   # :api: plugin
   def self.run
+    # Check if we running in IRB if so run IRB adapter
+    Merb::Config[:adapter] = 'irb' if Merb.running_irb?
     Merb.adapter = Merb::Rack::Adapter.get(Merb::Config[:adapter])
   end
 end
@@ -1304,6 +1309,19 @@ class Merb::BootLoader::RackUpApplication < Merb::BootLoader
   end
 end
 
+class Merb::BootLoader::BackgroundServices < Merb::BootLoader
+  # Start background services, such as the run_later worker thread.
+  #
+  # ==== Returns
+  # nil
+  #
+  # :api: plugin
+  def self.run
+    Merb::Worker.start unless Merb.testing? || Merb::Worker.started?
+    nil
+  end
+end
+
 class Merb::BootLoader::ReloadClasses < Merb::BootLoader
 
   class TimedExecutor
