@@ -153,6 +153,8 @@ module Kernel
     end
 
     if block = dep.require_block
+      # reset the require block so it doesn't get called a second time
+      dep.require_block = nil
       block.call
     end
 
@@ -434,7 +436,7 @@ module Kernel
   #
   # :api: public
   def extract_options_from_args!(args)
-    args.pop if Hash === args.last
+    args.pop if (args.last.instance_of?(Hash) || args.last.instance_of?(Mash))
   end
 
   # Checks that the given objects quack like the given conditions.
