@@ -2,8 +2,9 @@
 # testing helpers
 module Merb::Test::Helpers; end
 
+require "merb-core/test/helpers/cookie_jar"
+require "merb-core/test/helpers/mock_request_helper"
+require "merb-core/test/helpers/route_helper"
 require "merb-core/test/helpers/request_helper"
 require "merb-core/test/helpers/multipart_request_helper"
 require "merb-core/test/helpers/controller_helper"
-require "merb-core/test/helpers/route_helper"
-require "merb-core/test/helpers/view_helper"
\ No newline at end of file
